@@ -1,6 +1,11 @@
 # Copyright (c) 2010 Alexander Borgerth
 # See LICENSE for details.
 
+"""
+Some date related utils.
+"""
+
+
 _monthTranslateTable = {
     "january": 1,
     "february": 2,
@@ -17,6 +22,13 @@ _monthTranslateTable = {
 }
 
 def getMonth(month):
+    """
+    Return the month number given by name.
+
+    :parameters:
+        month
+            Name of month.
+    """
     if month not in _monthTranslateTable:
         raise ValueError("not a valid month!")
     return _monthTranslateTable[month]
