@@ -2,6 +2,7 @@
 # See LICENSE for details.
 
 import unittest
+import datetime
 from eztv.parser import Parser, Release
 
 class TestEztvParser(unittest.TestCase):
@@ -25,4 +26,5 @@ class TestEztvParser(unittest.TestCase):
         show = self.page.parse()[0]
         self.assertEqual(len(show.downloads), 4, "should have 4 downloads")
         self.assert_(show.releaseName.startswith("BBC Jimmys"))
+        self.assert_(isinstance(show.date, datetime.date))
 
